// ==========================================================================
// First Post
// ==========================================================================

.first-post {
	margin: 0 auto;
	max-width: 700px;
}

#title-prompt-text,
#mce_48-body,
.wp-editor-tabs {
	display: none;
}

#title {
	margin-bottom: 20px;
	border-radius: 3px;
	background: #fff;
	border: 1px solid #ddd;
	color:#222;
	font-size: 28px;
	font-weight: 700;
	box-shadow: inset 0 1px 1px rgba(0,0,0,0.1);

	@include breakpoint(tablet) {
		box-shadow: none;
	}

	@include breakpoint(phablet) {
		margin: 0;
		border: 0;
		border-top: 1px solid #ddd;
		border-radius: 0;
		font-size: 18px;
	}
}

#post-body {
	@include breakpoint(tablet) {
		margin: 0 20px;
	}
	@include breakpoint(phablet) {
		margin: 0;
	}
}

@include breakpoint(phablet) {
	#mce_2,
	#mce_6,
	#mce_7,
	#mce_8,
	#mce_9,
	#mce_12,
	#mce_13,
	#mce_14 {
		display: none;
	}

	#mce_28.mce-toolbar-grp {
		padding-right: 0;
	}
}

#mce_41-body,
#postdivrich {
	border: 1px solid #ddd;
	border-radius: 3px;

	@include breakpoint(phablet) {
		border-width: 1px 0;
		border-radius: 0;
	}
}

#mce_41 {
	background: #f9f9f9;
}

.submit-or-skip {
	text-align: center;

	@include breakpoint(phablet) {
		font-size: 14px;
	}
}

.skip-post {
	display:inline-block;
	margin-top:13px;
	margin-left:10px;
}

.mceContentBody {
	margin: 0 auto;
}

.confirmation-notice {
	margin: 23px 0 60px;
	padding: 30px;
	background: $light-gray;
	color: #666;

	@include breakpoint(phablet) {
		margin-bottom: 0;
		font-size: 14px;
	}
}
